1
0
forked from pool/virtualbox
virtualbox/vbox-default-os-type.diff
Larry Finger ff1d6fb65b Accepting request 414498 from home:luizluca:branches:Virtualization
bump to 5.1.2

I tried to keep all Suse customization as they are. Warning dialogs were ported to Qt5.
I did not check for added executables in the new release.

Compile tested on all current targets. Runtime tested on Tumbleweed, both host and guest.

OBS-URL: https://build.opensuse.org/request/show/414498
OBS-URL: https://build.opensuse.org/package/show/Virtualization/virtualbox?expand=0&rev=262
2016-07-26 16:15:55 +00:00

26 lines
1.3 KiB
Diff

Index: VirtualBox-5.1.2/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
===================================================================
--- VirtualBox-5.1.2.orig/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
+++ VirtualBox-5.1.2/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
@@ -327,15 +327,15 @@ void UINameAndSystemEditor::sltFamilyCha
if (iIndexWin7 != -1)
m_pComboType->setCurrentIndex(iIndexWin7);
}
/* Or select Ubuntu item for Linux family as default: */
else if (strFamilyId == "Linux")
{
- QString strDefaultID = "Ubuntu";
+ QString strDefaultID = "openSUSE";
if (ARCH_BITS == 64 && m_fSupportsHWVirtEx && m_fSupportsLongMode)
strDefaultID += "_64";
- const int iIndexUbuntu = m_pComboType->findData(strDefaultID, TypeID);
- if (iIndexUbuntu != -1)
- m_pComboType->setCurrentIndex(iIndexUbuntu);
+ const int iIndexOpenSUSE = m_pComboType->findData(strDefaultID, TypeID);
+ if (iIndexOpenSUSE != -1)
+ m_pComboType->setCurrentIndex(iIndexOpenSUSE);
}
/* Else simply select the first one present: */
else
@@ -327,15 +327,15 @@ void UINameAndSystemEditor::sltFamilyCha
m_pComboType->setCurrentIndex(iIndexWin7);
}
- /* Or select Ubuntu item for Linux family as default: */
+ /* Or select openSUSE item for Linux family as default: */
else if (strFamilyId == "Linux")
{